@@ -8,10 +8,37 @@
 #include "builtins.h"
 #include "pipe.h"
 
+#if PG_VERSION_NUM >= 150000
+
+#include "miscadmin.h"
+
+#endif
+
 /*  default value */
 char  *nls_date_format = NULL;
 char  *orafce_timezone = NULL;
 
+
+#if PG_VERSION_NUM >= 150000
+
+shmem_request_hook_type prev_shmem_request_hook = NULL;
+
+#endif
+
+#if PG_VERSION_NUM >= 150000
+
+static void
+orafce_shmem_request(void)
+{
+	if (prev_shmem_request_hook)
+		prev_shmem_request_hook();
+
+	RequestAddinShmemSpace(SHMEMMSGSZ);
+}
+
+#endif
+
+
 void
 _PG_init(void)
 {
@@ -22,8 +49,17 @@ _PG_init(void)
 
 #endif
 
+#if PG_VERSION_NUM >= 150000
+
+	prev_shmem_request_hook = shmem_request_hook;
+	shmem_request_hook = orafce_shmem_request;
+
+#else
+
 	RequestAddinShmemSpace(SHMEMMSGSZ);
 
+#endif
+
 	/* Define custom GUC variables. */
 	DefineCustomStringVariable("orafce.nls_date_format",
 									"Emulate oracle's date output behaviour.",
